@@ -88,16 +88,16 @@ class Table:
 	def __setitem__(self, key, value):
 		# 新規作成の場合
 		if key not in self:
-			# 値のファイルの作成
+			# 値のファイルの名前
 			hash_key = gen_hash(self.table_name, key)	# key文字列をhashに変換
 			filename = os.path.join(self.db.db_dir, "data", "%s.json"%hash_key)
-			fies[filename, "json"] = None
-			# 索引登録
+			# 索引登録・値ファイルの作成
 			index_filename = os.path.join(self.db.db_dir, "index.json")
 			with rename_lock(index_filename) as rlock:	# 競合編集防止
 				index = fies[rlock.filename, "json"]
 				index[self.table_name][key] = True
 				fies[rlock.filename, "json"] = index
+				fies[filename, "json"] = None	# 値ファイルの作成
 		# valueの書き込み
 		with self.lock(key) as rec:	# トランザクション処理 (レコードのロック)
 			rec.value = value
@@ -135,11 +135,20 @@ class Table:
 			yield key
 	# トランザクション処理 (レコードのロック)
 	def lock(self, key):
-		if key not in self: raise Exception("[json_stock error] The key '%s' does not exist."%key)
 		# valueが入っているファイルのlockを取得
 		hash_key = gen_hash(self.table_name, key)	# key文字列をhashに変換
 		filename = os.path.join(self.db.db_dir, "data", "%s.json"%hash_key)
-		self._rlock_dic[key] = rename_lock(filename)
+		if key in self:
+			self._rlock_dic[key] = rename_lock(filename)
+		else:
+			# レコードが元々存在しない場合
+			index_rlock = rename_lock(index_filename)	# 競合編集防止
+			index = fies[index_rlock.filename, "json"]
+			index[self.table_name][key] = True
+			fies[index_rlock.filename, "json"] = index
+			# ロックが解除されている瞬間がないように逆順で ロック→解除 する
+			self._rlock_dic[key] = rename_lock(filename)
+			index_rlock.unlock()
 		# locked record オブジェクトを返す (このlock recordがunlockされたときにfileもunlockする)
 		return LockedRecord(self, key)
 	# レコードのロック解除
